@@ -6,7 +6,7 @@
  */
 
 /*
- * Copyright 2009 Red Hat Inc., Durham, North Carolina.
+ * Copyright 2009--2014 Red Hat Inc., Durham, North Carolina.
  * All Rights Reserved.
  *
  * This library is free software; you can redistribute it and/or
@@ -36,6 +36,7 @@
 
 #include "cpe_name.h"
 #include "cpe_ctx_priv.h"
+#include "cpe_dict.h"
 
 #include "../common/public/oscap.h"
 #include "../common/util.h"
@@ -47,79 +48,6 @@
 OSCAP_HIDDEN_START;
  /* @endcond */
 
-/**
- * @struct cpe_check
- * Structure representing single CPE check.
- */
-struct cpe_check;
-
-/**
- * @struct cpe_reference
- * CPE dictionary item reference.
- */
-struct cpe_reference;
-
-/**
- * @struct cpe_item
- * Structure representing single CPE dictionary item.
- */
-struct cpe_item;
-
-/**
- * @struct cpe_dict_model
- * Structure representing a CPE dictionary.
- */
-struct cpe_dict_model;
-
-/**
- * @struct cpe_item_metadata
- * Structure representing metadata of CPE item
- */
-struct cpe_item_metadata;
-
-/**
- * @struct cpe_generator
- * Structure with information about document
- */
-struct cpe_generator;
-
-/**
- * @struct cpe_vendor
- * Structure with information about vendor
- */
-struct cpe_vendor;
-/**
- * @struct cpe_product
- * Product of some vendor
- */
-struct cpe_product;
-/**
- * @struct cpe_version
- * Version of product
- */
-struct cpe_version;
-/**
- * @struct cpe_update
- * Update of product version
- */
-struct cpe_update;
-/**
- * @struct cpe_edition
- * Edition of product update
- */
-struct cpe_edition;
-/**
- * @struct cpe_language
- * Language of product edition
- */
-struct cpe_language;
-
-/**
- * Function to parse XML to CPE dictionary model
- * @param file filename
- */
-struct cpe_dict_model *cpe_dict_model_parse_xml(const char *file);
-
 /**
  * Parse generator part of CPE dictionary XML file
  * @param ctx CPE Parser's context
@@ -150,6 +78,13 @@ struct cpe_vendor *cpe_vendor_parse(xmlTextReaderPtr reader);
  */
 struct cpe_dict_model *cpe_dict_model_parse(struct cpe_parser_ctx *ctx);
 
+/**
+ * Get a version info from xmlTextReader
+ * @param reader xmlTextReader
+ * @returns version string that shall be disposed by caller
+ */
+char *cpe_dict_detect_version_priv(xmlTextReader *reader);
+
 /**
  * Export function for CPE dictionary model
  * @param dict CPE dictionary structure
