@@ -95,8 +95,6 @@ struct cpe_name {
  */
 //static const char *CPE_PART_CHAR[] = { NULL, "h", "o", "a" };
 
-static const char CPE_SEP_CHAR = ':';
-
 static const struct oscap_string_map CPE_PART_MAP[] = {
 	{ CPE_PART_HW,   "h"  },
 	{ CPE_PART_OS,   "o"  },
@@ -212,7 +210,7 @@ bool cpe_set_field(struct cpe_name * cpe, int idx, const char *newval)
 		return false;
 	}
 
-	oscap_free(*fieldptr);
+	free(*fieldptr);
 	if (newval && strcmp(newval, "") == 0)
 		newval = NULL;
 	if (newval != NULL)
@@ -233,7 +231,7 @@ struct cpe_name *cpe_name_new(const char *cpestr)
 	if (cpestr && format == CPE_FORMAT_UNKNOWN)
 		return NULL;
 
-	cpe = oscap_alloc(sizeof(struct cpe_name));
+	cpe = malloc(sizeof(struct cpe_name));
 	if (cpe == NULL)
 		return NULL;
 	memset(cpe, 0, sizeof(struct cpe_name));	// zero memory
@@ -260,9 +258,9 @@ struct cpe_name *cpe_name_new(const char *cpestr)
 						// the rest are ~-encoded extended attributes
 						for (int j = 0; j < 5 && extended_attribs[1 + j] != NULL; ++j) {
 							if (!cpe_urldecode(extended_attribs[1 + j])) {
-								oscap_free(extended_attribs);
-								oscap_free(data_);
-								oscap_free(fields_);
+								free(extended_attribs);
+								free(data_);
+								free(fields_);
 								cpe_name_free(cpe);
 								return NULL;
 							}
@@ -270,13 +268,13 @@ struct cpe_name *cpe_name_new(const char *cpestr)
 							cpe_set_field(cpe, CPE_BASIC_FIELDNUM + j, extended_attribs[1 + j]);
 						}
 
-						oscap_free(extended_attribs); // we have used all the pointed to data
+						free(extended_attribs); // we have used all the pointed to data
 					}
 				}
 
 				if (!cpe_urldecode(fields_[i])) {
-					oscap_free(data_);
-					oscap_free(fields_);
+					free(data_);
+					free(fields_);
 					cpe_name_free(cpe);
 					return NULL;
 				}
@@ -284,8 +282,8 @@ struct cpe_name *cpe_name_new(const char *cpestr)
 				cpe_set_field(cpe, i, fields_[i]);
 			}
 
-			oscap_free(data_);
-			oscap_free(fields_);
+			free(data_);
+			free(fields_);
 		}
 		else if (format == CPE_FORMAT_STRING) {
 			char *data_ = strdup(cpestr + 8);	// without 'cpe:2.3:'
@@ -293,8 +291,8 @@ struct cpe_name *cpe_name_new(const char *cpestr)
 			for (i = 0; fields_[i] && i < CPE_TOTAL_FIELDNUM; ++i)
 			{
 				if (!cpestring_comp_decode(fields_[i])) {
-					oscap_free(data_);
-					oscap_free(fields_);
+					free(data_);
+					free(fields_);
 					cpe_name_free(cpe);
 					return NULL;
 				}
@@ -302,8 +300,8 @@ struct cpe_name *cpe_name_new(const char *cpestr)
 				cpe_set_field(cpe, i, fields_[i]);
 			}
 
-			oscap_free(data_);
-			oscap_free(fields_);
+			free(data_);
+			free(fields_);
 		}
 		else if (format == CPE_FORMAT_WFN)
 		{
@@ -314,7 +312,7 @@ struct cpe_name *cpe_name_new(const char *cpestr)
 
 struct cpe_name * cpe_name_clone(struct cpe_name * old_name)
 {
-        struct cpe_name * new_name = oscap_alloc(sizeof(struct cpe_name));
+        struct cpe_name * new_name = malloc(sizeof(struct cpe_name));
         if (new_name == NULL) 
             return NULL;
 
@@ -390,7 +388,7 @@ static char *cpe_urlencode(const char *str)
 	// allocate enough space
 	// in the worst case (all characters need to be replaced), the memory
 	// we will need is 3 times the size of input, + 1 for the terminating \0
-	char *result = oscap_alloc(strlen(str) * 3 * sizeof(char) + 1);
+	char *result = malloc(strlen(str) * 3 * sizeof(char) + 1);
 	char *out = result;
 
 	for (const char *in = str; *in != '\0'; ++in, ++out) {
@@ -454,7 +452,7 @@ static char *cpestring_comp_encode(const char *str)
 	// allocate enough space
 	// in the worst case (all characters need to be replaced), the memory
 	// we will need is 3 times the size of input, + 1 for the terminating \0
-	char *result = oscap_alloc(strlen(str) * 3 * sizeof(char) + 1);
+	char *result = malloc(strlen(str) * 3 * sizeof(char) + 1);
 	char *out = result;
 
 	for (const char *in = str; *in != '\0'; ++in, ++out) {
@@ -517,11 +515,11 @@ static char *cpe_pack_extended_attributes(const struct cpe_name *cpe)
 			encoded_other
 	);
 
-	oscap_free(encoded_edition);
-	oscap_free(encoded_sw_edition);
-	oscap_free(encoded_target_sw);
-	oscap_free(encoded_target_hw);
-	oscap_free(encoded_other);
+	free(encoded_edition);
+	free(encoded_sw_edition);
+	free(encoded_target_sw);
+	free(encoded_target_hw);
+	free(encoded_other);
 
 	return ret;
 }
@@ -668,7 +666,7 @@ char *cpe_name_get_as_format(const struct cpe_name *cpe, cpe_format_t format)
 			len += strlen(part[i]);
 		}
 
-		result = oscap_alloc(len * sizeof(char));
+		result = malloc(len * sizeof(char));
 		if (result == NULL)
 			return NULL;
 
@@ -679,7 +677,7 @@ char *cpe_name_get_as_format(const struct cpe_name *cpe, cpe_format_t format)
 
 		// free individual parts
 		for (int j = 0; j < CPE_BASIC_FIELDNUM; ++j)
-			oscap_free(part[j]);
+			free(part[j]);
 
 		// trim trailing colons
 		while (result[--i] == ':')
@@ -704,7 +702,7 @@ char *cpe_name_get_as_format(const struct cpe_name *cpe, cpe_format_t format)
 			len += strlen(part[i]);
 		}
 
-		result = oscap_alloc(len * sizeof(char));
+		result = malloc(len * sizeof(char));
 		if (result == NULL)
 			return NULL;
 
@@ -716,7 +714,7 @@ char *cpe_name_get_as_format(const struct cpe_name *cpe, cpe_format_t format)
 
 		// free individual parts
 		for (int j = 0; j < CPE_TOTAL_FIELDNUM; ++j)
-			oscap_free(part[j]);
+			free(part[j]);
 
 		return result;
 	}
@@ -747,7 +745,7 @@ int cpe_name_write(const struct cpe_name *cpe, FILE * f)
 
 	ret = fprintf(f, "%s", uri);
 
-	oscap_free(uri);
+	free(uri);
 	return ret;
 }
 
@@ -759,7 +757,7 @@ void cpe_name_free(struct cpe_name *cpe)
 	int i;
 	for (i = 0; i < CPE_TOTAL_FIELDNUM; ++i)
 		cpe_set_field(cpe, i, NULL);
-	oscap_free(cpe);
+	free(cpe);
 }
 
 const char * cpe_name_supported(void)
