@@ -11,7 +11,7 @@
  */
 
 /*
- * Copyright 2009--2013 Red Hat Inc., Durham, North Carolina.
+ * Copyright 2009--2014 Red Hat Inc., Durham, North Carolina.
  * All Rights Reserved.
  *
  * This library is free software; you can redistribute it and/or
@@ -40,6 +40,7 @@
 #include "oscap.h"
 #include "cpe_name.h"
 #include "oscap_text.h"
+#include "oscap_source.h"
 
 /**
  * @struct cpe_dict_model
@@ -435,6 +436,12 @@ struct cpe_item_metadata *cpe_item_metadata_new(void);
  * @{
  */
 
+/// @memberof cpe_item
+bool cpe_item_set_name(struct cpe_item *item, const struct cpe_name *new_name);
+
+/// @memberof cpe_item
+bool cpe_item_set_deprecated_by(struct cpe_item *item, const struct cpe_name *new_deprecated_by);
+
 /// @memberof cpe_item
 bool cpe_item_set_deprecation_date(struct cpe_item *item, const char *new_deprecation_date);
 
@@ -520,6 +527,9 @@ bool cpe_item_add_title(struct cpe_item *item, struct oscap_text *new_title);
  */
 OSCAP_DEPRECATED(bool cpe_item_add_note(struct cpe_item *item, struct oscap_text *new_title));
 
+/// @memberof cpe_dict_model
+bool cpe_dict_model_add_item(struct cpe_dict_model *dict, struct cpe_item *new_item);
+
 /// @memberof cpe_dict_model
 bool cpe_dict_model_add_vendor(struct cpe_dict_model *dict, struct cpe_vendor *new_vendor);
 
@@ -868,8 +878,10 @@ const char * cpe_dict_model_supported(void);
  * Detects which version the given CPE file is
  *
  * Deallocate the result after use with "free(..)".
+ * @deprecated This function has been deprecated by @ref oscap_source_get_schema_version.
+ * This function may be dropped from later versions of the library.
  */
-char * cpe_dict_detect_version(const char* file);
+OSCAP_DEPRECATED(char *cpe_dict_detect_version(const char* file));
 
 /** 
  * Verify wether given CPE is known according to specified dictionary
@@ -921,8 +933,19 @@ void cpe_dict_model_export(const struct cpe_dict_model *dict, const char *file);
  * @param file filename
  * @return new dictionary
  * @retval NULL on failure
+ * @deprecated This function has been deprecated by @ref cpe_dict_model_import_source.
+ * This function may be dropped from later versions of the library.
  */
-struct cpe_dict_model *cpe_dict_model_import(const char *file);
+OSCAP_DEPRECATED(struct cpe_dict_model *cpe_dict_model_import(const char *file));
+
+/**
+ * Load new CPE dictionary from an oscap_source
+ * @memberof cpe_dict_model
+ * @param source The oscap_source to parse content from
+ * @returns new dictionary or NULL
+ */
+struct cpe_dict_model *cpe_dict_model_import_source(struct oscap_source *source);
+
 
 /**
  * Sets the origin file hint
