@@ -57,7 +57,7 @@ typedef struct oval_sysent {
 
 struct oval_sysent *oval_sysent_new(struct oval_syschar_model *model)
 {
-	oval_sysent_t *sysent = (oval_sysent_t *) oscap_alloc(sizeof(oval_sysent_t));
+	oval_sysent_t *sysent = (oval_sysent_t *) malloc(sizeof(oval_sysent_t));
 	if (sysent == NULL)
 		return NULL;
 
@@ -98,16 +98,16 @@ void oval_sysent_free(struct oval_sysent *sysent)
 		return;
 
 	if (sysent->name != NULL)
-		oscap_free(sysent->name);
+		free(sysent->name);
 	if (sysent->value != NULL)
-		oscap_free(sysent->value);
+		free(sysent->value);
 	if (sysent->record_fields)
 		oval_collection_free_items(sysent->record_fields, (oscap_destruct_func) oval_record_field_free);
 
 	sysent->name = NULL;
 	sysent->value = NULL;
 
-	oscap_free(sysent);
+	free(sysent);
 }
 
 bool oval_sysent_iterator_has_more(struct oval_sysent_iterator *oc_sysent)
@@ -175,7 +175,7 @@ void oval_sysent_set_name(struct oval_sysent *sysent, char *name)
 {
 	__attribute__nonnull__(sysent);
 	if (sysent->name != NULL)
-		oscap_free(sysent->name);
+		free(sysent->name);
 	sysent->name = name;
 }
 
@@ -201,7 +201,7 @@ void oval_sysent_set_value(struct oval_sysent *sysent, char *value)
 {
 	__attribute__nonnull__(sysent);
 	if (sysent->value != NULL)
-		oscap_free(sysent->value);
+		free(sysent->value);
 	sysent->value = oscap_strdup(value);
 }
 
@@ -288,7 +288,9 @@ void oval_sysent_to_dom(struct oval_sysent *sysent, xmlDoc * doc, xmlNode * pare
 	if (mask && !xmlStrcmp(root_node->name, BAD_CAST OVAL_ROOT_ELM_RESULTS)) {
 		sysent_tag = xmlNewTextChild(parent, ent_ns, BAD_CAST tagname, BAD_CAST "");
 	} else {
-		sysent_tag = xmlNewTextChild(parent, ent_ns, BAD_CAST tagname, BAD_CAST content);
+		xmlChar *encoded_content = xmlEncodeEntitiesReentrant(doc, BAD_CAST content);
+		sysent_tag = xmlNewChild(parent, ent_ns, BAD_CAST tagname, encoded_content);
+		xmlFree(encoded_content);
 	}
 
 	if (mask) {
