@@ -106,7 +106,7 @@ typedef struct oval_variable_restriction {
 struct oval_variable_possible_value *oval_variable_possible_value_new(const char *hint, const char *value)
 {
 	struct oval_variable_possible_value *pv;
-	pv = oscap_alloc(sizeof(oval_variable_possible_value_t));
+	pv = malloc(sizeof(oval_variable_possible_value_t));
 	pv->hint = oscap_strdup(hint);
 	pv->value = oscap_strdup(value);
 	return pv;
@@ -115,16 +115,50 @@ struct oval_variable_possible_value *oval_variable_possible_value_new(const char
 void oval_variable_possible_value_free(struct oval_variable_possible_value *pv)
 {
 	if (pv != NULL) {
-		oscap_free(pv->hint);
-		oscap_free(pv->value);
-		oscap_free(pv);
+		free(pv->hint);
+		free(pv->value);
+		free(pv);
 	}
 }
 
+char* oval_variable_possible_value_get_hint(struct oval_variable_possible_value* pv)
+{
+    __attribute__nonnull__(pv);
+
+    return pv->hint;
+}
+
+char* oval_variable_possible_value_get_value(struct oval_variable_possible_value* pv)
+{
+    __attribute__nonnull__(pv);
+
+    return pv->value;
+}
+
+bool oval_variable_possible_value_iterator_has_more(struct oval_variable_possible_value_iterator* iter)
+{
+	return oval_collection_iterator_has_more((struct oval_iterator*)iter);
+}
+
+struct oval_variable_possible_value* oval_variable_possible_value_iterator_next(struct oval_variable_possible_value_iterator* iter)
+{
+	return (struct oval_variable_possible_value*)oval_collection_iterator_next((struct oval_iterator*)iter);
+}
+
+void oval_variable_possible_value_iterator_free(struct oval_variable_possible_value_iterator* iter)
+{
+	oval_collection_iterator_free((struct oval_iterator*)iter);
+}
+
+int oval_variable_possible_value_iterator_remaining(struct oval_variable_possible_value_iterator* iter)
+{
+	return oval_collection_iterator_remaining((struct oval_iterator*)iter);
+}
+
 struct oval_variable_possible_restriction *oval_variable_possible_restriction_new(oval_operator_t operator, const char *hint)
 {
 	struct oval_variable_possible_restriction *pr;
-	pr = oscap_alloc(sizeof(oval_variable_possible_restriction_t));
+	pr = malloc(sizeof(oval_variable_possible_restriction_t));
 	pr->operator = operator;
 	pr->hint = oscap_strdup(hint);
 	pr->restrictions = oval_collection_new();
@@ -134,9 +168,9 @@ struct oval_variable_possible_restriction *oval_variable_possible_restriction_ne
 void oval_variable_possible_restriction_free(struct oval_variable_possible_restriction *pr)
 {
 	if (pr != NULL) {
-		oscap_free(pr->hint);
+		free(pr->hint);
 		oval_collection_free_items(pr->restrictions, (oscap_destruct_func) oval_variable_restriction_free);
-		oscap_free(pr);
+		free(pr);
 	}
 }
 
@@ -152,15 +186,51 @@ struct oval_iterator *oval_variable_possible_restriction_get_restrictions(struct
 	return oval_collection_iterator(possible_restriction->restrictions);
 }
 
+struct oval_variable_restriction_iterator *oval_variable_possible_restriction_get_restrictions2(struct oval_variable_possible_restriction *possible_restriction)
+{
+	return (struct oval_variable_restriction_iterator*)oval_collection_iterator(possible_restriction->restrictions);
+}
+
 oval_operator_t oval_variable_possible_restriction_get_operator(struct oval_variable_possible_restriction *possible_restriction)
 {
+	__attribute__nonnull__(possible_restriction);
+
 	return possible_restriction->operator;
 }
 
+char* oval_variable_possible_restriction_get_hint(struct oval_variable_possible_restriction* possible_restriction)
+{
+	__attribute__nonnull__(possible_restriction);
+
+	return possible_restriction->hint;
+}
+
+
+bool oval_variable_possible_restriction_iterator_has_more(struct oval_variable_possible_restriction_iterator* iter)
+{
+	return oval_collection_iterator_has_more((struct oval_iterator*)iter);
+}
+
+struct oval_variable_possible_restriction* oval_variable_possible_restriction_iterator_next(struct oval_variable_possible_restriction_iterator* iter)
+{
+	return (struct oval_variable_possible_restriction*)oval_collection_iterator_next((struct oval_iterator*)iter);
+}
+
+void oval_variable_possible_restriction_iterator_free(struct oval_variable_possible_restriction_iterator* iter)
+{
+	oval_collection_iterator_free((struct oval_iterator*)iter);
+}
+
+int oval_variable_possible_restriction_iterator_remaining(struct oval_variable_possible_restriction_iterator* iter)
+{
+	return oval_collection_iterator_remaining((struct oval_iterator*)iter);
+}
+
+
 struct oval_variable_restriction *oval_variable_restriction_new(oval_operation_t operation, const char *value)
 {
 	struct oval_variable_restriction *r;
-	r = oscap_alloc(sizeof(oval_variable_restriction_t));
+	r = malloc(sizeof(oval_variable_restriction_t));
 	r->operation = operation;
 	r->value = oscap_strdup(value);
 	return r;
@@ -169,11 +239,46 @@ struct oval_variable_restriction *oval_variable_restriction_new(oval_operation_t
 void oval_variable_restriction_free(struct oval_variable_restriction *r)
 {
 	if (r != NULL) {
-		oscap_free(r->value);
-		oscap_free(r);
+		free(r->value);
+		free(r);
 	}
 }
 
+oval_operation_t oval_variable_restriction_get_operation(struct oval_variable_restriction* restriction)
+{
+    __attribute__nonnull__(restriction);
+
+    return restriction->operation;
+}
+
+char* oval_variable_restriction_get_value(struct oval_variable_restriction* restriction)
+{
+    __attribute__nonnull__(restriction);
+
+    return restriction->value;
+}
+
+bool oval_variable_restriction_iterator_has_more(struct oval_variable_restriction_iterator* iter)
+{
+	return oval_collection_iterator_has_more((struct oval_iterator*)iter);
+}
+
+struct oval_variable_restriction* oval_variable_restriction_iterator_next(struct oval_variable_restriction_iterator* iter)
+{
+	return (struct oval_variable_restriction*)oval_collection_iterator_next((struct oval_iterator*)iter);
+}
+
+void oval_variable_restriction_iterator_free(struct oval_variable_restriction_iterator* iter)
+{
+	oval_collection_iterator_free((struct oval_iterator*)iter);
+}
+
+int oval_variable_restriction_iterator_remaining(struct oval_variable_restriction_iterator* iter)
+{
+	return oval_collection_iterator_remaining((struct oval_iterator*)iter);
+}
+
+
 bool oval_variable_iterator_has_more(struct oval_variable_iterator
 				     *oc_variable)
 {
@@ -282,6 +387,16 @@ struct oval_iterator *oval_variable_get_possible_values(struct oval_variable *va
 	}
 }
 
+struct oval_variable_possible_value_iterator *oval_variable_get_possible_values2(struct oval_variable *variable)
+{
+	if (variable->type == OVAL_VARIABLE_EXTERNAL) {
+		oval_variable_EXTERNAL_t *var = (oval_variable_EXTERNAL_t *) variable;
+		return (struct oval_variable_possible_value_iterator*)oval_collection_iterator(var->possible_values);
+	} else {
+		return (struct oval_variable_possible_value_iterator*)oval_collection_iterator_new();
+	}
+}
+
 struct oval_iterator *oval_variable_get_possible_restrictions(struct oval_variable *variable)
 {
 	if (variable->type == OVAL_VARIABLE_EXTERNAL) {
@@ -292,6 +407,16 @@ struct oval_iterator *oval_variable_get_possible_restrictions(struct oval_variab
 	}
 }
 
+struct oval_variable_possible_restriction_iterator *oval_variable_get_possible_restrictions2(struct oval_variable *variable)
+{
+	if (variable->type == OVAL_VARIABLE_EXTERNAL) {
+		oval_variable_EXTERNAL_t *var = (oval_variable_EXTERNAL_t *) variable;
+		return (struct oval_variable_possible_restriction_iterator*)oval_collection_iterator(var->possible_restrictions);
+	} else {
+		return (struct oval_variable_possible_restriction_iterator*)oval_collection_iterator_new();
+	}
+}
+
 bool oval_variable_contains_value(struct oval_variable *variable, const char* o_value_text)
 {
 	if (variable == NULL)
@@ -354,23 +479,63 @@ int oval_syschar_model_compute_variable(struct oval_syschar_model *sysmod, struc
         return 0;
 }
 
+static int _dump_variable_values(struct oval_variable *variable)
+{
+	if (variable->flag != SYSCHAR_FLAG_COMPLETE && variable->flag != SYSCHAR_FLAG_INCOMPLETE) {
+		dI("Variable '%s' has no values.", variable->id);
+		return 0;
+	}
+
+	struct oval_value_iterator *val_itr = oval_variable_get_values(variable);
+	if (!oval_value_iterator_has_more(val_itr)) {
+		oval_value_iterator_free(val_itr);
+		return -1;
+	}
+
+	struct oscap_string *val_dump = oscap_string_new();
+	oscap_string_append_char(val_dump, '\"');
+	while(1) {
+		struct oval_value *val = oval_value_iterator_next(val_itr);
+		if (oval_value_cast(val, variable->datatype) != 0) {
+			oval_value_iterator_free(val_itr);
+			oscap_string_free(val_dump);
+			return -1;
+		}
+		oscap_string_append_string(val_dump, oval_value_get_text(val));
+		if (!oval_value_iterator_has_more(val_itr)) {
+			break;
+		}
+		oscap_string_append_string(val_dump, "\", \"");
+	}
+	oscap_string_append_char(val_dump, '\"');
+
+	dI("Variable '%s' has values %s.", variable->id, oscap_string_get_cstr(val_dump));
+
+	oscap_string_free(val_dump);
+	oval_value_iterator_free(val_itr);
+
+	return 0;
+}
+
 int oval_probe_query_variable(oval_probe_session_t *sess, struct oval_variable *variable)
 {
 	oval_variable_LOCAL_t *var;
 	struct oval_component *component;
-	struct oval_value_iterator *val_itr;
-	struct oscap_string *val_dump;
 
 	__attribute__nonnull__(variable);
 
-	if (variable->type != OVAL_VARIABLE_LOCAL)
+	dI("Querying variable '%s'.", variable->id);
+
+	if (variable->type != OVAL_VARIABLE_LOCAL) {
+		dI("Variable '%s' is not local, skipping.", variable->id);
+		_dump_variable_values(variable);
 		return 0;
+	}
 
 	var = (oval_variable_LOCAL_t *) variable;
 	if (var->flag != SYSCHAR_FLAG_UNKNOWN)
 		return 0;
 
-	dI("Querying variable '%s'.", var->id);
 	component = var->component;
         if (component) {
 		if (!var->values)
@@ -381,45 +546,9 @@ int oval_probe_query_variable(oval_probe_session_t *sess, struct oval_variable *
 		return -1;
         }
 
-	switch (var->flag) {
-	case SYSCHAR_FLAG_COMPLETE:
-	case SYSCHAR_FLAG_INCOMPLETE:
-		break;
-	default:
-		dI("Variable '%s' has no values.", var->id);
-		return 0;
-	}
-
-	val_itr = oval_variable_get_values(variable);
-	if (!oval_value_iterator_has_more(val_itr)) {
-		oval_value_iterator_free(val_itr);
+	if (_dump_variable_values(variable) != 0) {
 		var->flag = SYSCHAR_FLAG_ERROR;
-		return 0;
 	}
-
-	val_dump = oscap_string_new();
-	oscap_string_append_char(val_dump, '\"');
-	while(1) {
-		struct oval_value *val;
-
-		val = oval_value_iterator_next(val_itr);
-		if (oval_value_cast(val, var->datatype) != 0) {
-			oval_value_iterator_free(val_itr);
-			var->flag = SYSCHAR_FLAG_ERROR;
-			oscap_string_free(val_dump);
-			return 0;
-		}
-		oscap_string_append_string(val_dump, oval_value_get_text(val));
-		if (!oval_value_iterator_has_more(val_itr)) {
-			break;
-		}
-		oscap_string_append_string(val_dump, "\", \"");
-	}
-	oscap_string_append_char(val_dump, '\"');
-	dI("Variable '%s' has values %s.", var->id, oscap_string_get_cstr(val_dump));
-	oscap_string_free(val_dump);
-	oval_value_iterator_free(val_itr);
-
 	return 0;
 }
 
@@ -447,7 +576,7 @@ struct oval_variable *oval_variable_new(struct oval_definition_model *model, con
 	case OVAL_VARIABLE_CONSTANT:{
 			oval_variable_CONSTANT_t *cvar;
 
-			variable = (oval_variable_t *) oscap_alloc(sizeof(oval_variable_CONSTANT_t));
+			variable = (oval_variable_t *) malloc(sizeof(oval_variable_CONSTANT_t));
 			if (variable == NULL)
 				return NULL;
 
@@ -459,7 +588,7 @@ struct oval_variable *oval_variable_new(struct oval_definition_model *model, con
 	case OVAL_VARIABLE_EXTERNAL:{
 			oval_variable_EXTERNAL_t *evar;
 
-			variable = (oval_variable_t *) oscap_alloc(sizeof(oval_variable_EXTERNAL_t));
+			variable = (oval_variable_t *) malloc(sizeof(oval_variable_EXTERNAL_t));
 			if (variable == NULL)
 				return NULL;
 
@@ -473,7 +602,7 @@ struct oval_variable *oval_variable_new(struct oval_definition_model *model, con
 	case OVAL_VARIABLE_LOCAL:{
 			oval_variable_LOCAL_t *lvar;
 
-			variable = (oval_variable_t *) oscap_alloc(sizeof(oval_variable_LOCAL_t));
+			variable = (oval_variable_t *) malloc(sizeof(oval_variable_LOCAL_t));
 			if (variable == NULL)
 				return NULL;
 
@@ -484,7 +613,7 @@ struct oval_variable *oval_variable_new(struct oval_definition_model *model, con
 		}
 		break;
 	case OVAL_VARIABLE_UNKNOWN:{
-			variable = (oval_variable_t *) oscap_alloc(sizeof(oval_variable_UNKNOWN_t));
+			variable = (oval_variable_t *) malloc(sizeof(oval_variable_UNKNOWN_t));
 			if (variable == NULL)
 				return NULL;
 
@@ -546,34 +675,34 @@ struct oval_variable *oval_variable_clone(struct oval_definition_model *new_mode
 			evar = (oval_variable_EXTERNAL_t *) new_variable;
 			old_evar = (oval_variable_EXTERNAL_t *) old_variable;
 
-			struct oval_iterator *old_pv_itr;
-			old_pv_itr = oval_variable_get_possible_values(old_variable);
-			while (oval_collection_iterator_has_more(old_pv_itr)) {
+			struct oval_variable_possible_value_iterator *old_pv_itr;
+			old_pv_itr = oval_variable_get_possible_values2(old_variable);
+			while (oval_variable_possible_value_iterator_has_more(old_pv_itr)) {
 				struct oval_variable_possible_value *old_pv, *new_pv;
-				old_pv = oval_collection_iterator_next(old_pv_itr);
+				old_pv = oval_variable_possible_value_iterator_next(old_pv_itr);
 				new_pv = oval_variable_possible_value_new(old_pv->hint, old_pv->value);
 				oval_variable_add_possible_value(new_variable, new_pv);
 			}
-			oval_collection_iterator_free(old_pv_itr);
+			oval_variable_possible_value_iterator_free(old_pv_itr);
 
-			struct oval_iterator *old_pr_itr;
-			old_pr_itr = oval_variable_get_possible_restrictions(old_variable);
-			while (oval_collection_iterator_has_more(old_pr_itr)) {
+			struct oval_variable_possible_restriction_iterator *old_pr_itr;
+			old_pr_itr = oval_variable_get_possible_restrictions2(old_variable);
+			while (oval_variable_possible_restriction_iterator_has_more(old_pr_itr)) {
 				struct oval_variable_possible_restriction *old_pr, *new_pr;
-				old_pr = oval_collection_iterator_next(old_pr_itr);
+				old_pr = oval_variable_possible_restriction_iterator_next(old_pr_itr);
 				new_pr = oval_variable_possible_restriction_new(old_pr->operator, old_pr->hint);
-				struct oval_iterator *old_r_itr;
-				old_r_itr = oval_variable_possible_restriction_get_restrictions(old_pr);
-				while (oval_collection_iterator_has_more(old_r_itr)) {
+				struct oval_variable_restriction_iterator *old_r_itr;
+				old_r_itr = oval_variable_possible_restriction_get_restrictions2(old_pr);
+				while (oval_variable_restriction_iterator_has_more(old_r_itr)) {
 					struct oval_variable_restriction *old_r, *new_r;
-					old_r = oval_collection_iterator_next(old_r_itr);
+					old_r = oval_variable_restriction_iterator_next(old_r_itr);
 					new_r = oval_variable_restriction_new(old_r->operation, old_r->value);
 					oval_variable_possible_restriction_add_restriction(new_pr, new_r);
 				}
-				oval_collection_iterator_free(old_r_itr);
+				oval_variable_restriction_iterator_free(old_r_itr);
 				oval_variable_add_possible_restriction(new_variable, new_pr);
 			}
-			oval_collection_iterator_free(old_pr_itr);
+			oval_variable_possible_restriction_iterator_free(old_pr_itr);
 
 			evar->values_ref = old_evar->values_ref;
 
@@ -612,9 +741,9 @@ void oval_variable_free(struct oval_variable *variable)
 {
 	if (variable) {
 		if (variable->id)
-			oscap_free(variable->id);
+			free(variable->id);
 		if (variable->comment)
-			oscap_free(variable->comment);
+			free(variable->comment);
 		variable->id = variable->comment = NULL;
 
 		switch (variable->type) {
@@ -653,7 +782,7 @@ void oval_variable_free(struct oval_variable *variable)
 			break;
 		}
 
-		oscap_free(variable);
+		free(variable);
 	}
 }
 
@@ -713,7 +842,7 @@ void oval_variable_set_comment(struct oval_variable *variable, char *comm)
 	__attribute__nonnull__(variable);
 
 	if (variable->comment != NULL)
-		oscap_free(variable->comment);
+		free(variable->comment);
 	variable->comment = oscap_strdup(comm);
 
 }
@@ -804,13 +933,13 @@ static int oval_value_satisfies_possible_restriction(struct oval_value *value, s
 	oval_operator_t operator = pr->operator;
 	struct oresults results;
 	ores_clear(&results);
-	struct oval_iterator *restrictions = oval_variable_possible_restriction_get_restrictions(pr);
-	while (oval_collection_iterator_has_more(restrictions)) {
-		struct oval_variable_restriction *r = oval_collection_iterator_next(restrictions);
+	struct oval_variable_restriction_iterator *restrictions = oval_variable_possible_restriction_get_restrictions2(pr);
+	while (oval_variable_restriction_iterator_has_more(restrictions)) {
+		struct oval_variable_restriction *r = oval_variable_restriction_iterator_next(restrictions);
 		oval_result_t result = oval_str_cmp_str(r->value, datatype, text, r->operation);
 		ores_add_res(&results, result);
 	}
-	oval_collection_iterator_free(restrictions);
+	oval_variable_restriction_iterator_free(restrictions);
 	return (ores_get_result_byopr(&results, operator) == OVAL_RESULT_TRUE);
 }
 
@@ -899,8 +1028,8 @@ static int _oval_variable_parse_local_tag(xmlTextReaderPtr reader, struct oval_p
 	if (return_code != 0) {
 		dW("Parsing of %s terminated by an error at <%s>, line %d.", variable->id, tagname, xmlTextReaderGetParserLineNumber(reader));
 	}
-	oscap_free(tagname);
-	oscap_free(namespace);
+	free(tagname);
+	free(namespace);
 	return return_code;
 }
 
@@ -915,7 +1044,7 @@ static int _oval_variable_parse_restriction_tag(xmlTextReaderPtr reader, struct
 		struct oval_variable_restriction *restriction = oval_variable_restriction_new(operation, value);
 		oval_variable_possible_restriction_add_restriction(pr, restriction);
 		return_code = 0;
-		oscap_free(value);
+		free(value);
 	} else {
 		return_code = 1;
 	}
@@ -934,27 +1063,27 @@ static int _oval_variable_parse_external_tag(xmlTextReaderPtr reader, struct ova
 			char *value = (char *)xmlTextReaderValue(reader);
 			struct oval_variable_possible_value *pv = oval_variable_possible_value_new(hint, value);
 			oval_variable_add_possible_value(variable, pv);
-			oscap_free(value);
+			free(value);
 			return_code = 0;
 		} else {
 			return_code = 1;
 		}
-		oscap_free(hint);
+		free(hint);
 	} else if (strcmp(tagname, "possible_restriction") == 0) {
 		oval_operator_t operator = oval_operator_parse(reader, "operator", OVAL_OPERATOR_AND);
 		char *hint = (char *)xmlTextReaderGetAttribute(reader, BAD_CAST "hint");
 		struct oval_variable_possible_restriction *pr = oval_variable_possible_restriction_new(operator, hint);
 		oval_variable_add_possible_restriction(variable, pr);
 		return_code = oval_parser_parse_tag(reader, context, _oval_variable_parse_restriction_tag, pr);
-		oscap_free(hint);
+		free(hint);
 	} else {
 		return_code = 1;
 	}
 	if (return_code != 0) {
 		dW("Parsing of %s terminated by an error at <%s>, line %d.", variable->id, tagname, xmlTextReaderGetParserLineNumber(reader));
 	}
-	oscap_free(tagname);
-	oscap_free(namespace);
+	free(tagname);
+	free(namespace);
 	return return_code;
 }
 
@@ -984,8 +1113,8 @@ static int _oval_variable_parse_constant_tag(xmlTextReaderPtr reader, struct ova
 	oval_value_parse_tag(reader, context, _const_tag_consumer, variable);
 
  out:
-	oscap_free(tagname);
-	oscap_free(namespace);
+	free(tagname);
+	free(namespace);
 	return 0;
 }
 
@@ -1044,10 +1173,10 @@ int oval_variable_parse_tag(xmlTextReaderPtr reader, struct oval_parser_context
 		return_code = 1;
 	}
 
-	oscap_free(tagname);
-	oscap_free(id);
-	oscap_free(comm);
-	oscap_free(version);
+	free(tagname);
+	free(id);
+	free(comm);
+	free(version);
 
 	return return_code;
 }
@@ -1072,40 +1201,40 @@ static xmlNode *_oval_VARIABLE_EXTERNAL_to_dom(struct oval_variable *variable, x
 	xmlNs *ns_definitions = xmlSearchNsByHref(doc, parent, OVAL_DEFINITIONS_NAMESPACE);
 	xmlNode *variable_node = xmlNewTextChild(parent, ns_definitions, BAD_CAST "external_variable", NULL);
 
-	struct oval_iterator *possible_values = oval_variable_get_possible_values(variable);
-	while (oval_collection_iterator_has_more(possible_values)) {
-		struct oval_variable_possible_value *pv = oval_collection_iterator_next(possible_values);
+	struct oval_variable_possible_value_iterator *possible_values = oval_variable_get_possible_values2(variable);
+	while (oval_variable_possible_value_iterator_has_more(possible_values)) {
+		struct oval_variable_possible_value *pv = oval_variable_possible_value_iterator_next(possible_values);
 		xmlNode *possible_value_node = xmlNewTextChild(variable_node, ns_definitions, BAD_CAST "possible_value", BAD_CAST pv->value);
 		xmlNewProp(possible_value_node, BAD_CAST "hint", BAD_CAST pv->hint);
 	}
-	oval_collection_iterator_free(possible_values);
+	oval_variable_possible_value_iterator_free(possible_values);
 
 	oval_schema_version_t schema_version = oval_definition_model_get_core_schema_version(variable->model);
 	bool serialize_operator = oval_schema_version_cmp(schema_version, OVAL_SCHEMA_VERSION(5.11)) >= 0;
-	struct oval_iterator *possible_restrictions = oval_variable_get_possible_restrictions(variable);
-	while (oval_collection_iterator_has_more(possible_restrictions)) {
-		struct oval_variable_possible_restriction *pr = oval_collection_iterator_next(possible_restrictions);
-		struct oval_iterator *restrictions = oval_variable_possible_restriction_get_restrictions(pr);
+	struct oval_variable_possible_restriction_iterator *possible_restrictions = oval_variable_get_possible_restrictions2(variable);
+	while (oval_variable_possible_restriction_iterator_has_more(possible_restrictions)) {
+		struct oval_variable_possible_restriction *pr = oval_variable_possible_restriction_iterator_next(possible_restrictions);
+		struct oval_variable_restriction_iterator *restrictions = oval_variable_possible_restriction_get_restrictions2(pr);
 		/* Create "possible_restriction" node only if there will be some
 		 * "restriction" children, because each "possible_restriction"
 		 * node must have at least one "restriction" child.
 		 */
-		if (oval_collection_iterator_has_more(restrictions)) {
+		if (oval_variable_restriction_iterator_has_more(restrictions)) {
 			xmlNode *possible_restriction_node = xmlNewTextChild(variable_node, ns_definitions, BAD_CAST "possible_restriction", NULL);
 			/* Attribute "operator" is new in OVAL 5.11, we don't serialize it in older OVAL versions */
 			if (serialize_operator) {
 				xmlNewProp(possible_restriction_node, BAD_CAST "operator", BAD_CAST oval_operator_get_text(pr->operator));
 			}
 			xmlNewProp(possible_restriction_node, BAD_CAST "hint", BAD_CAST pr->hint);
-			while (oval_collection_iterator_has_more(restrictions)) {
-				struct oval_variable_restriction *r = oval_collection_iterator_next(restrictions);
+			while (oval_variable_restriction_iterator_has_more(restrictions)) {
+				struct oval_variable_restriction *r = oval_variable_restriction_iterator_next(restrictions);
 				xmlNode *restriction_node = xmlNewTextChild(possible_restriction_node, ns_definitions, BAD_CAST "restriction", BAD_CAST r->value);
 				xmlNewProp(restriction_node, BAD_CAST "operation", BAD_CAST oval_operation_get_text(r->operation));
 			}
 		}
-		oval_collection_iterator_free(restrictions);
+		oval_variable_restriction_iterator_free(restrictions);
 	}
-	oval_collection_iterator_free(possible_restrictions);
+	oval_variable_possible_restriction_iterator_free(possible_restrictions);
 
 	return variable_node;
 }
