@@ -52,7 +52,7 @@ static int __abort_cb(void *n, void *u)
 
         pthread_cancel(thr->tid);
 
-	coll->thr = oscap_realloc(coll->thr, sizeof(SEAP_msg_t *) * ++coll->cnt);
+	coll->thr = realloc(coll->thr, sizeof(SEAP_msg_t *) * ++coll->cnt);
 	coll->thr[coll->cnt - 1] = thr;
 
 	return (0);
@@ -64,7 +64,9 @@ void *probe_signal_handler(void *arg)
 	siginfo_t siinf;
 	sigset_t  siset;
 
+#if defined(HAVE_PTHREAD_SETNAME_NP)
 	pthread_setname_np(pthread_self(), "signal_handler");
+#endif
 
 	sigemptyset(&siset);
 	sigaddset(&siset, SIGHUP);
@@ -80,7 +82,7 @@ void *probe_signal_handler(void *arg)
                 dW("prctl(PR_SET_PDEATHSIG, SIGTERM) failed");
 #endif
        
-	dI("Signal handler ready");
+	dD("Signal handler ready");
 	switch (errno = pthread_barrier_wait(&OSCAP_GSYM(th_barrier)))
 	{
 	case 0:
@@ -93,7 +95,7 @@ void *probe_signal_handler(void *arg)
 
 	while (sigwaitinfo(&siset, &siinf) != -1) {
 
-		dI("Received signal %d from %u (%s)",
+		dD("Received signal %d from %u (%s)",
 		   siinf.si_signo, (unsigned int)siinf.si_pid,
 		   getppid() == siinf.si_pid ? "parent" : "not my parent");
 
@@ -154,10 +156,10 @@ void *probe_signal_handler(void *arg)
 				}
 #endif
 				SEAP_msg_free(coll.thr[coll.cnt - 1]->msg);
-                                oscap_free(coll.thr[coll.cnt - 1]);
+                                free(coll.thr[coll.cnt - 1]);
 			}
 
-			oscap_free(coll.thr);
+			free(coll.thr);
 			goto exitloop;
 		}
                 case SIGUSR2:
