@@ -1,12 +1,6 @@
 #ifndef PROBE_COMMON_H
 #define PROBE_COMMON_H
 
-/**
- * probe option IDs
- */
-#define PROBE_VARREF_HANDLING 0
-#define PROBE_RESULT_CACHING  1
-
 /**
  * probe errors (send by probes in SEAP error packets)
  */
