@@ -207,9 +207,9 @@ static int get_runlevel_sysv (struct runlevel_req *req, struct runlevel_rep **re
 			closedir(rc_dir);
 
 			if (rep_lst == NULL) {
-				rep_lst = *rep = oscap_alloc(sizeof (struct runlevel_rep));
+				rep_lst = *rep = malloc(sizeof (struct runlevel_rep));
 			} else {
-				rep_lst->next = oscap_alloc(sizeof (struct runlevel_rep));
+				rep_lst->next = malloc(sizeof (struct runlevel_rep));
 				rep_lst = rep_lst->next;
 			}
 
@@ -377,6 +377,12 @@ static int is_solaris (void)
         return (stat ("/etc/release", &st)   == 0);
 }
 
+static int is_oracle (void)
+{
+        struct stat st;
+        return (stat ("/etc/oracle-release", &st)   == 0);
+}
+
 static int is_wrlinux(void)
 {
 	return parse_os_release("cpe:/o:windriver:wrlinux");
@@ -394,6 +400,7 @@ typedef struct {
 
 const distro_tbl_t distro_tbl[] = {
         { &is_debian,   &get_runlevel_debian   },
+        { &is_oracle,   &get_runlevel_redhat   },
         { &is_redhat,   &get_runlevel_redhat   },
         { &is_slack,    &get_runlevel_slack    },
         { &is_gentoo,   &get_runlevel_gentoo   },
@@ -499,9 +506,9 @@ int probe_main (probe_ctx *ctx, void *arg)
                         probe_item_collect(ctx, item);
 
 			next_rep = reply_st->next;
-			oscap_free(reply_st->service_name);
-			oscap_free(reply_st->runlevel);
-			oscap_free(reply_st);
+			free(reply_st->service_name);
+			free(reply_st->runlevel);
+			free(reply_st);
 			reply_st = next_rep;
 		}
         }
