@@ -41,6 +41,12 @@ typedef struct oval_probe_session oval_probe_session_t;
  */
 oval_probe_session_t *oval_probe_session_new(struct oval_syschar_model *model);
 
+/**
+ * Reinitialize already allocated probe session inplace
+ * @param model system characteristics model
+ */
+void oval_probe_session_reinit(oval_probe_session_t *sess, struct oval_syschar_model *model);
+
 /**
  * Destroy probe session. All state information created during the lifetime
  * of the session is freed, resources used by probes are freed using the probe
@@ -85,3 +91,4 @@ int oval_probe_session_sethandler(oval_probe_session_t *sess, oval_subtype_t typ
 struct oval_syschar_model *oval_probe_session_getmodel(oval_probe_session_t *sess);
 
 #endif /* OVAL_PROBE_SESSION */
+/// @}
