@@ -14,7 +14,7 @@
  */
 
 /*
- * Copyright 2009-2010 Red Hat Inc., Durham, North Carolina.
+ * Copyright 2009--2014 Red Hat Inc., Durham, North Carolina.
  * All Rights Reserved.
  *
  * This library is free software; you can redistribute it and/or
@@ -33,12 +33,15 @@
  *
  * Authors:
  *      "David Niemoller" <David.Niemoller@g2-inc.com>
+ *      Šimon Lukašík
  */
 
 
 #ifndef OVAL_SYSTEM_CHARACTERISTICS
 #define OVAL_SYSTEM_CHARACTERISTICS
 
+#include "oscap.h"
+#include "oscap_source.h"
 #include "oval_types.h"
 #include "oval_definitions.h"
 
@@ -193,6 +196,16 @@ struct oval_variable_binding_iterator;
  */
 struct oval_syschar_model *oval_syschar_model_new(struct oval_definition_model *definition_model);
 
+/**
+ * Import the content from the oscap_source into an oval_syschar_model.
+ * If imported content specifies a model entity that is already registered within the model its content is overwritten.
+ * @param model the merge target model
+ * @param source The oscap_source to import data from.
+ * @return zero on success or non zero value if an error occurred
+ * @memberof oval_syschar_model
+ */
+int oval_syschar_model_import_source(struct oval_syschar_model *model, struct oscap_source *source);
+
 /**
  * Import the content from the file into an oval_syschar_model.
  * If imported content specifies a model entity that is already registered within the model its content is overwritten.
@@ -200,8 +213,11 @@ struct oval_syschar_model *oval_syschar_model_new(struct oval_definition_model *
  * @param file filename
  * @return zero on success or non zero value if an error occurred
  * @memberof oval_syschar_model
+ * @deprecated This function has been deprecated and it may be dropped from later
+ * OpenSCAP releases. Please use oval_syschar_model_import_source instead.
+ *
  */
-int oval_syschar_model_import(struct oval_syschar_model *model, const char *file);
+OSCAP_DEPRECATED(int oval_syschar_model_import(struct oval_syschar_model *model, const char *file));
 /**
  * Copy an oval_syschar_model.
  * @return A copy of the specified @ref oval_syschar_model.
@@ -425,6 +441,19 @@ void oval_syschar_set_flag(struct oval_syschar *model, oval_syschar_collection_f
  * @memberof oval_syschar
  */
 void oval_syschar_set_object(struct oval_syschar *, struct oval_object *);
+/**
+ * Gets the variable_instance attribute of the syschar.
+ * @memberof oval_syschar
+ * @returns currect variable_instance attribute assigned
+ */
+int oval_syschar_get_variable_instance(const struct oval_syschar *syschar);
+/**
+ * Sets the variable_instance attribute of the syschar.
+ * @memberof oval_syschar
+ * @param syschar collected object
+ * @param variable_instance_in new settings of variable_instance attribute
+ */
+void oval_syschar_set_variable_instance(struct oval_syschar *syschar, int variable_instance_in);
 /**
  * @memberof oval_syschar
  */
