@@ -108,7 +108,7 @@ struct oval_result_system *oval_result_system_new(struct oval_results_model *mod
 	__attribute__nonnull__(model);
 	oval_result_system_t *sys;
 
-	sys = (oval_result_system_t *) oscap_alloc(sizeof(oval_result_system_t));
+	sys = (oval_result_system_t *) malloc(sizeof(oval_result_system_t));
 	if (sys == NULL)
 		return NULL;
 
@@ -149,7 +149,7 @@ void oval_result_system_free(struct oval_result_system *sys)
 	sys->syschar_model = NULL;
 	sys->tests = NULL;
 
-	oscap_free(sys);
+	free(sys);
 }
 
 bool oval_result_system_iterator_has_more(struct oval_result_system_iterator *sys) {
@@ -293,7 +293,7 @@ static int oval_result_system_parse(xmlTextReaderPtr reader, struct oval_parser_
                 dW("Parsing of <%s> terminated by an error at line %d.", localName, xmlTextReaderGetParserLineNumber(reader));
         }
 
-	oscap_free(localName);
+	free(localName);
 	return return_code;
 }
 
@@ -322,8 +322,8 @@ int oval_result_system_parse_tag(xmlTextReaderPtr reader, struct oval_parser_con
                 dW("Parsing of <%s> terminated by an error at line %d.", tagname, xmlTextReaderGetParserLineNumber(reader));
         }
 
-        oscap_free(tagname);
-        oscap_free(namespace);
+        free(tagname);
+        free(namespace);
 
 	return return_code;
 }
@@ -406,6 +406,8 @@ static void _oval_result_definition_to_dom_based_on_directives(struct oval_resul
 			/* collect the tests that are referenced from reported definitions */
 			if (criteria)
 				_oval_result_system_scan_criteria_for_references(criteria, tstmap);
+		} else if (content == OVAL_DIRECTIVE_CONTENT_THIN) {
+			// NOOP
 		}
 	}
 }
@@ -504,8 +506,9 @@ xmlNode *oval_result_system_to_dom(struct oval_result_system * sys,
 	}
 	oval_smc_iterator_free(result_tests);
 
+	bool export_sys_char = oval_results_model_get_export_system_characteristics(results_model);
 	oval_syschar_model_to_dom(syschar_model, doc, system_node, 
-				  (oval_syschar_resolver *) _oval_result_system_resolve_syschar, sysmap);
+				  (oval_syschar_resolver *) _oval_result_system_resolve_syschar, sysmap, export_sys_char);
 
 	oval_string_map_free(sysmap, NULL);
 	oval_string_map_free(objmap, NULL);
