@@ -34,6 +34,8 @@
 #include "common/util.h"
 #include "common/list.h"
 #include "common/oscap_acquire.h"
+#include "common/oscap_string.h"
+#include "common/debug_priv.h"
 #include "sce_engine_api.h"
 
 #include <stdlib.h>
@@ -50,12 +52,14 @@
 #endif
 #include <limits.h>
 #include <unistd.h>
+#include <libgen.h>
 
 struct sce_check_result
 {
 	char* href;
 	char* basename;
 	char* std_out;
+	char* std_err;
 	int exit_code;
 	struct oscap_stringlist* environment_variables;
 	xccdf_test_result_type_t xccdf_result;
@@ -63,10 +67,11 @@ struct sce_check_result
 
 struct sce_check_result* sce_check_result_new(void)
 {
-	struct sce_check_result* ret = oscap_alloc(sizeof(struct sce_check_result));
+	struct sce_check_result* ret = malloc(sizeof(struct sce_check_result));
 	ret->href = NULL;
 	ret->basename = NULL;
 	ret->std_out = NULL;
+	ret->std_err = NULL;
 	ret->environment_variables = oscap_stringlist_new();
 	ret->xccdf_result = XCCDF_RESULT_UNKNOWN;
 
@@ -78,23 +83,19 @@ void sce_check_result_free(struct sce_check_result* v)
 	if (!v)
 		return;
 
-	if (v->href)
-		oscap_free(v->href);
-	if (v->basename)
-		oscap_free(v->basename);
-	if (v->std_out)
-		oscap_free(v->std_out);
+	free(v->href);
+	free(v->basename);
+	free(v->std_out);
+	free(v->std_err);
 
 	oscap_stringlist_free(v->environment_variables);
 
-	oscap_free(v);
+	free(v);
 }
 
 void sce_check_result_set_href(struct sce_check_result* v, const char* href)
 {
-	if (v->href)
-		oscap_free(v->href);
-
+	free(v->href);
 	v->href = strdup(href);
 }
 
@@ -105,9 +106,7 @@ const char* sce_check_result_get_href(struct sce_check_result* v)
 
 void sce_check_result_set_basename(struct sce_check_result* v, const char* base_name)
 {
-	if (v->basename)
-		oscap_free(v->basename);
-
+	free(v->basename);
 	v->basename = strdup(base_name);
 }
 
@@ -118,9 +117,7 @@ const char* sce_check_result_get_basename(struct sce_check_result* v)
 
 void sce_check_result_set_stdout(struct sce_check_result* v, const char* _stdout)
 {
-	if (v->std_out)
-		oscap_free(v->std_out);
-
+	free(v->std_out);
 	v->std_out = strdup(_stdout);
 }
 
@@ -129,6 +126,17 @@ const char* sce_check_result_get_stdout(struct sce_check_result* v)
 	return v->std_out;
 }
 
+void sce_check_result_set_stderr(struct sce_check_result* v, const char* _stderr)
+{
+	free(v->std_err);
+	v->std_err = strdup(_stderr);
+}
+
+const char* sce_check_result_get_stderr(struct sce_check_result* v)
+{
+	return v->std_err;
+}
+
 void sce_check_result_set_exit_code(struct sce_check_result* v, int exit_code)
 {
 	v->exit_code = exit_code;
@@ -181,8 +189,15 @@ void sce_check_result_export(struct sce_check_result* v, const char* target_file
 	oscap_string_iterator_free(it);
 	fprintf(f, "\t</sceres:environment>\n");
 	fprintf(f, "\t<sceres:stdout><![CDATA[\n");
-	fwrite(v->std_out, 1, strlen(v->std_out), f);
+	size_t ret = fwrite(v->std_out, 1, strlen(v->std_out), f);
+	if (ret < strlen(v->std_out))
+		oscap_seterr(OSCAP_EFAMILY_SCE, "Failed to write stdout result to %s.\n", target_file);
 	fprintf(f, "\t]]></sceres:stdout>\n");
+	fprintf(f, "\t<sceres:stderr><![CDATA[\n");
+	ret = fwrite(v->std_err, 1, strlen(v->std_err), f);
+	if (ret < strlen(v->std_err))
+		oscap_seterr(OSCAP_EFAMILY_SCE, "Failed to write stderr result to %s.\n", target_file);
+	fprintf(f, "\t]]></sceres:stderr>\n");
 	fprintf(f, "\t<sceres:exit_code>%i</sceres:exit_code>\n", sce_check_result_get_exit_code(v));
 	fprintf(f, "\t<sceres:result>%s</sceres:result>\n", xccdf_test_result_type_get_text(sce_check_result_get_xccdf_result(v)));
 	fprintf(f, "</sceres:sce_results>\n");
@@ -196,7 +211,7 @@ struct sce_session
 
 struct sce_session* sce_session_new(void)
 {
-	struct sce_session* ret = oscap_alloc(sizeof(struct sce_session));
+	struct sce_session* ret = malloc(sizeof(struct sce_session));
 	ret->results = oscap_list_new();
 
 	return ret;
@@ -208,7 +223,7 @@ void sce_session_free(struct sce_session* s)
 		return;
 
 	oscap_list_free(s->results, (oscap_destruct_func) sce_check_result_free);
-	oscap_free(s);
+	free(s);
 }
 
 void sce_session_reset(struct sce_session* s)
@@ -238,7 +253,7 @@ void sce_session_export_to_directory(struct sce_session* s, const char* director
 		struct sce_check_result * result = sce_check_result_iterator_next(it);
 		char* target = oscap_sprintf("%s/%s.result.xml", directory, sce_check_result_get_basename(result));
 		sce_check_result_export(result, target);
-		oscap_free(target);
+		free(target);
 	}
 
 	sce_check_result_iterator_free(it);
@@ -252,7 +267,7 @@ struct sce_parameters
 
 struct sce_parameters* sce_parameters_new(void)
 {
-	struct sce_parameters *ret = oscap_alloc(sizeof(struct sce_parameters));
+	struct sce_parameters *ret = malloc(sizeof(struct sce_parameters));
 	ret->xccdf_directory = NULL;
 	ret->session = NULL;
 
@@ -264,18 +279,16 @@ void sce_parameters_free(struct sce_parameters* v)
 	if (!v)
 		return;
 
-	if (v->xccdf_directory)
-		oscap_free(v->xccdf_directory);
-	if (v->session)
-		sce_session_free(v->session);
+	free(v->xccdf_directory);
+	sce_session_free(v->session);
 
-	oscap_free(v);
+	free(v);
 }
 
 void sce_parameters_set_xccdf_directory(struct sce_parameters* v, const char* value)
 {
 	if (v->xccdf_directory)
-		oscap_free(v->xccdf_directory);
+		free(v->xccdf_directory);
 
 	v->xccdf_directory = value == NULL ? NULL : strdup(value);
 }
@@ -287,12 +300,7 @@ const char* sce_parameters_get_xccdf_directory(struct sce_parameters* v)
 
 void sce_parameters_set_session(struct sce_parameters* v, struct sce_session* value)
 {
-	if (v->session)
-	{
-		sce_session_free(v->session);
-		v->session = NULL;
-	}
-
+	sce_session_free(v->session);
 	v->session = value;
 }
 
@@ -306,6 +314,38 @@ void sce_parameters_allocate_session(struct sce_parameters* v)
 	sce_parameters_set_session(v, sce_session_new());
 }
 
+static void _pipe_try_read_into_string(int fd, struct oscap_string *string, bool *eof)
+{
+	// FIXME: Read by larger chunks in the future
+	char readbuf;
+	while (true) {
+		const int read_status = read(fd, &readbuf, 1);
+		if (read_status == 1) {  // successful read
+			if (readbuf == '&') {
+				// & is a special case, we have to "escape" it manually
+				// (all else will eventually get handled by libxml)
+				oscap_string_append_string(string, "&amp;");
+			} else {
+				oscap_string_append_char(string, readbuf);
+			}
+		}
+		else if (read_status == 0) {  // EOF
+			*eof = true;
+			break;
+		}
+		else {
+			if (errno == EAGAIN) {
+				// NOOP, we are waiting for more input
+				break;
+			}
+			else {
+				*eof = true;  // signal EOF to exit the loops
+				break;
+			}
+		}
+	}
+}
+
 xccdf_test_result_type_t sce_engine_eval_rule(struct xccdf_policy *policy, const char *rule_id, const char *id, const char *href,
 		struct xccdf_value_binding_iterator *value_binding_it,
 		struct xccdf_check_import_iterator *check_import_it,
@@ -326,7 +366,7 @@ xccdf_test_result_type_t sce_engine_eval_rule(struct xccdf_policy *policy, const
 		// with a different XCCDF directory can find it?
 		oscap_seterr(OSCAP_EFAMILY_SCE, "SCE couldn't find script file '%s'. "
 				"Expected location: '%s'.", href, tmp_href);
-		oscap_free(tmp_href);
+		free(tmp_href);
 		return XCCDF_RESULT_NOT_CHECKED;
 	}
 
@@ -335,7 +375,7 @@ xccdf_test_result_type_t sce_engine_eval_rule(struct xccdf_policy *policy, const
 		// again, only to provide helpful error message
 		oscap_seterr(OSCAP_EFAMILY_SCE, "SCE has found script file '%s' at '%s' "
 				"but it isn't executable!", href, tmp_href);
-		oscap_free(tmp_href);
+		free(tmp_href);
 		return XCCDF_RESULT_ERROR;
 	}
 
@@ -348,7 +388,7 @@ xccdf_test_result_type_t sce_engine_eval_rule(struct xccdf_policy *policy, const
 	};
 
 	// bound values in KEY=VALUE form, ready to be passed as environment variables
-	char ** env_values = oscap_alloc(10 * sizeof(char * ));
+	char ** env_values = malloc(10 * sizeof(char * ));
 	size_t env_value_count = 10;
 
 	env_values[0] = "PATH=/bin:/sbin:/usr/bin:/usr/sbin";
@@ -367,11 +407,15 @@ xccdf_test_result_type_t sce_engine_eval_rule(struct xccdf_policy *policy, const
 	{
 		struct xccdf_value_binding* binding = xccdf_value_binding_iterator_next(value_binding_it);
 
-		env_values = oscap_realloc(env_values, (env_value_count + 3) * sizeof(char*));
+		env_values = realloc(env_values, (env_value_count + 3) * sizeof(char*));
 
 		char* name = xccdf_value_binding_get_name(binding);
 		xccdf_value_type_t type = xccdf_value_binding_get_type(binding);
-		char* value = xccdf_value_binding_get_value(binding);
+		char* value = xccdf_value_binding_get_setvalue(binding);
+		if (value == NULL)
+		{
+			value = xccdf_value_binding_get_value(binding);
+		}
 		xccdf_operator_t operator = xccdf_value_binding_get_operator(binding);
 
 		char* type_str;
@@ -435,20 +479,21 @@ xccdf_test_result_type_t sce_engine_eval_rule(struct xccdf_policy *policy, const
 		env_value_count++;
 	}
 
-	env_values = oscap_realloc(env_values, (env_value_count + 1) * sizeof(char*));
+	env_values = realloc(env_values, (env_value_count + 1) * sizeof(char*));
 	env_values[env_value_count] = NULL;
 
 	// We open a pipe for communication with the forked process
-	int pipefd[2];
-	if (pipe(pipefd) == -1)
+	int stdout_pipefd[2];
+	int stderr_pipefd[2];
+	if (pipe(stdout_pipefd) == -1 || pipe(stderr_pipefd) == -1)
 	{
 		perror("pipe");
 		// the first 9 values (0 to 8) are compiled in
 		for (size_t i = 9; i < env_value_count; ++i)
 		{
-			oscap_free(env_values[i]);
+			free(env_values[i]);
 		}
-		oscap_free(env_values);
+		free(env_values);
 		return XCCDF_RESULT_ERROR;
 	}
 
@@ -462,17 +507,19 @@ xccdf_test_result_type_t sce_engine_eval_rule(struct xccdf_policy *policy, const
 
 		if (fork_result == 0)
 		{
-		    // we won't read from the pipe, so close the reading fd
-		    close(pipefd[0]);
+		    // we won't read from the pipes, so close the reading fd
+		    close(stdout_pipefd[0]);
+		    close(stderr_pipefd[0]);
 
-		    // forward stdout and stderr to the opened pipe
-			dup2(pipefd[1], fileno(stdout));
-			dup2(pipefd[1], fileno(stderr));
+			// forward stdout and stderr to our custom opened pipes
+			dup2(stdout_pipefd[1], fileno(stdout));
+			dup2(stderr_pipefd[1], fileno(stderr));
 
-			// we duplicated the file description twice, we can close the original
-			// one now, stdout and stderr will be closed properly after the execved
+			// we duplicated the file descriptors twice, we can close the original
+			// ones now, stdout and stderr will be closed properly after the execved
 			// script/executable finishes
-			close(pipefd[1]);
+			close(stdout_pipefd[1]);
+			close(stderr_pipefd[1]);
 
 			// before we execute the script, lets make sure we get SIGTERM when
 			// oscap is killed, crashes or otherwise terminates
@@ -495,10 +542,62 @@ xccdf_test_result_type_t sce_engine_eval_rule(struct xccdf_policy *policy, const
 		}
 		else
 		{
-			// we won't write to the pipe, so close the writing fd
-			close(pipefd[1]);
+			// we won't write to the pipes, so close the writing fd
+			close(stdout_pipefd[1]);
+			close(stderr_pipefd[1]);
 
-			char* stdout_buffer = oscap_acquire_pipe_to_string(pipefd[0]);
+			const int flag_stdout = fcntl(stdout_pipefd[0], F_GETFL, 0);
+			if (flag_stdout == -1) {
+				oscap_seterr(OSCAP_EFAMILY_SCE, "Failed to obtain status of stdout pipe: %s",
+						strerror(errno));
+				return XCCDF_RESULT_ERROR;
+			}
+			int retval = fcntl(stdout_pipefd[0], F_SETFL, flag_stdout | O_NONBLOCK);
+			if (retval == -1) {
+				oscap_seterr(OSCAP_EFAMILY_SCE,
+						"Failed to set nonblocking flag on stdout pipe: %s",
+						strerror(errno));
+				return XCCDF_RESULT_ERROR;
+			}
+
+			const int flag_stderr = fcntl(stderr_pipefd[0], F_GETFL, 0);
+			if (flag_stderr == -1) {
+				oscap_seterr(OSCAP_EFAMILY_SCE,
+						"Failed to obtain status of stderr pipe: %s",
+						strerror(errno));
+				return XCCDF_RESULT_ERROR;
+			}
+			retval = fcntl(stderr_pipefd[0], F_SETFL, flag_stderr | O_NONBLOCK);
+			if (retval == -1) {
+				oscap_seterr(OSCAP_EFAMILY_SCE,
+						"Failed to set nonblocking flag on stderr pipe: %s",
+						strerror(errno));
+				return XCCDF_RESULT_ERROR;
+			}
+
+			// we have to read from both pipes at the same time to avoid stalling
+			struct oscap_string *stdout_string = oscap_string_new();
+			struct oscap_string *stderr_string = oscap_string_new();
+
+			bool stdout_eof = false;
+			bool stderr_eof = false;
+
+			while (!stdout_eof || !stderr_eof) {
+				if (!stdout_eof)
+					_pipe_try_read_into_string(stdout_pipefd[0], stdout_string, &stdout_eof);
+
+				if (!stderr_eof)
+					_pipe_try_read_into_string(stderr_pipefd[0], stderr_string, &stderr_eof);
+
+				// sleep for 10ms to avoid wasting CPU
+				usleep(10 * 1000);
+			}
+
+			close(stdout_pipefd[0]);
+			close(stderr_pipefd[0]);
+
+			char *stdout_buffer = oscap_string_bequeath(stdout_string);
+			char *stderr_buffer = oscap_string_bequeath(stderr_string);
 
 			// we are the parent process
 			int wstatus;
@@ -519,6 +618,7 @@ xccdf_test_result_type_t sce_engine_eval_rule(struct xccdf_policy *policy, const
 				sce_check_result_set_href(check_result, tmp_href);
 				sce_check_result_set_basename(check_result, basename(tmp_href));
 				sce_check_result_set_stdout(check_result, stdout_buffer);
+				sce_check_result_set_stderr(check_result, stderr_buffer);
 				sce_check_result_set_exit_code(check_result, WEXITSTATUS(wstatus));
 				sce_check_result_set_xccdf_result(check_result, (xccdf_test_result_type_t)raw_result);
 
@@ -533,9 +633,9 @@ xccdf_test_result_type_t sce_engine_eval_rule(struct xccdf_policy *policy, const
 			// the first 10 values (0 to 9) are compiled in
 			for (size_t i = 10; i < env_value_count; ++i)
 			{
-				oscap_free(env_values[i]);
+				free(env_values[i]);
 			}
-			oscap_free(env_values);
+			free(env_values);
 
 			// lets interpret the check imports passed to us
 			xccdf_check_import_iterator_reset(check_import_it);
@@ -548,10 +648,15 @@ xccdf_test_result_type_t sce_engine_eval_rule(struct xccdf_policy *policy, const
 				{
 					xccdf_check_import_set_content(check_import, stdout_buffer);
 				}
+				else if (strcmp(name, "stderr") == 0)
+				{
+					xccdf_check_import_set_content(check_import, stderr_buffer);
+				}
 			}
 
-			oscap_free(tmp_href);
-			oscap_free(stdout_buffer);
+			free(tmp_href);
+			free(stdout_buffer);
+			free(stderr_buffer);
 
 			return (xccdf_test_result_type_t)raw_result;
 		}
@@ -561,12 +666,14 @@ xccdf_test_result_type_t sce_engine_eval_rule(struct xccdf_policy *policy, const
 		// the first 9 values (0 to 8) are compiled in
 		for (size_t i = 9; i < env_value_count; ++i)
 		{
-			oscap_free(env_values[i]);
+			free(env_values[i]);
 		}
-		oscap_free(env_values);
+		free(env_values);
 
-		close(pipefd[0]);
-		close(pipefd[1]);
+		close(stdout_pipefd[0]);
+		close(stdout_pipefd[1]);
+		close(stderr_pipefd[0]);
+		close(stderr_pipefd[1]);
 		return XCCDF_RESULT_ERROR;
 	}
 }
