@@ -45,6 +45,7 @@
 #include "DS/public/ds_sds_session.h"
 #include "DS/ds_sds_session_priv.h"
 #include "DS/rds_priv.h"
+#include "DS/sds_priv.h"
 #include "OVAL/results/oval_results_impl.h"
 #include "source/xslt_priv.h"
 #include "XCCDF/xccdf_impl.h"
@@ -96,6 +97,7 @@ struct xccdf_session {
 	struct {
 		char *arf_file;				///< Path to ARF file to export
 		char *xccdf_file;			///< Path to XCCDF file to export
+		char *xccdf_stig_viewer_file;		///< Path to STIG Viewer XCCDF file to export
 		char *report_file;			///< Path to HTML file to eport
 		bool oval_results;			///< Shall be the OVAL results files exported?
 		bool oval_variables;			///< Shall be the OVAL variable files exported?
@@ -227,18 +229,9 @@ static struct oscap_source* xccdf_session_create_arf_source(struct xccdf_session
 
 	if (xccdf_session_is_sds(session)) {
 		sds_source = session->source;
-	}
-	else {
-		if (!session->temp_dir)
-			session->temp_dir = oscap_acquire_temp_dir();
-		if (session->temp_dir == NULL)
-			return NULL;
-
-		char *sds_path = malloc(PATH_MAX * sizeof(char));
-		snprintf(sds_path, PATH_MAX, "%s/sds.xml", session->temp_dir);
-		ds_sds_compose_from_xccdf(oscap_source_readable_origin(session->source), sds_path);
-		sds_source = oscap_source_new_from_file(sds_path);
-		free(sds_path);
+	} else {
+		xmlDocPtr sds_doc = ds_sds_compose_xmlDoc_from_xccdf_source(session->source);
+		sds_source = oscap_source_new_from_xmlDoc(sds_doc, NULL);
 	}
 
 	session->oval.arf_report = ds_rds_create_source(sds_source, session->xccdf.result_source, session->oval.result_sources, session->oval.results_mapping, session->oval.arf_report_mapping, session->export.arf_file);
@@ -254,6 +247,7 @@ void xccdf_session_free(struct xccdf_session *session)
 		return;
 	free(session->xccdf.profile_id);
 	free(session->export.xccdf_file);
+	free(session->export.xccdf_stig_viewer_file);
 	free(session->export.report_file);
 	free(session->export.arf_file);
 	_xccdf_session_free_oval_result_sources(session);
@@ -422,6 +416,13 @@ bool xccdf_session_set_xccdf_export(struct xccdf_session *session, const char *x
 	return true;
 }
 
+bool xccdf_session_set_xccdf_stig_viewer_export(struct xccdf_session *session, const char *xccdf_stig_viewer_file)
+{
+	free(session->export.xccdf_stig_viewer_file);
+	session->export.xccdf_stig_viewer_file = oscap_strdup(xccdf_stig_viewer_file);
+	return true;
+}
+
 bool xccdf_session_set_report_export(struct xccdf_session *session, const char *report_file)
 {
 	free(session->export.report_file);
@@ -438,15 +439,59 @@ bool xccdf_session_set_profile_id(struct xccdf_session *session, const char *pro
 	return true;
 }
 
-// 0 = no error, 1 = no matches, 2 = multiple matches
+static const char *xccdf_profiles_match_profile_id(struct xccdf_profile_iterator *profile_it, const char *profile_suffix, int *match_status)
+{
+	const char *full_profile_id = NULL;
+	bool multiple = false;
+	while (xccdf_profile_iterator_has_more(profile_it)) {
+		struct xccdf_profile *profile = xccdf_profile_iterator_next(profile_it);
+		const char *profile_id = xccdf_profile_get_id(profile);
+
+		if(oscap_str_endswith(profile_id, profile_suffix)) {
+			if (full_profile_id != NULL) {
+				oscap_seterr(OSCAP_EFAMILY_OSCAP, "Multiple matches found:\n%s\n%s\n",
+					full_profile_id, profile_id);
+				multiple = true;
+				break;
+			} else {
+				full_profile_id = profile_id;
+			}
+		}
+	}
+	xccdf_profile_iterator_free(profile_it);
+	if (match_status != NULL) {
+		if (multiple) {
+			*match_status = OSCAP_PROFILE_MULTIPLE_MATCHES;
+			full_profile_id = NULL;
+		} else if (full_profile_id == NULL) {
+			*match_status = OSCAP_PROFILE_NO_MATCH;
+		} else {
+			*match_status = OSCAP_PROFILE_MATCH_OK;
+		}
+	}
+	return full_profile_id;
+}
+
+const char *xccdf_tailoring_match_profile_id(struct xccdf_tailoring *tailoring, const char *profile_suffix, int *match_status)
+{
+	struct xccdf_profile_iterator *profile_it = xccdf_tailoring_get_profiles(tailoring);
+	return xccdf_profiles_match_profile_id(profile_it, profile_suffix, match_status);
+}
+
+const char *xccdf_benchmark_match_profile_id(struct xccdf_benchmark *bench, const char *profile_suffix, int *match_status)
+{
+	struct xccdf_profile_iterator *profile_it = xccdf_benchmark_get_profiles(bench);
+	return xccdf_profiles_match_profile_id(profile_it, profile_suffix, match_status);
+}
+
 int xccdf_session_set_profile_id_by_suffix(struct xccdf_session *session, const char *profile_suffix)
 {
 	const char *full_profile_id = NULL;
 	struct xccdf_benchmark *bench = xccdf_policy_model_get_benchmark(session->xccdf.policy_model);
-	bool multiple = false;
 
 	// Tailoring Profiles
 	struct xccdf_tailoring *tailoring = xccdf_policy_model_get_tailoring(session->xccdf.policy_model);
+	int return_code = OSCAP_PROFILE_NO_MATCH;
 	if (tailoring != NULL)   {
 		struct xccdf_profile_iterator *profit_tailoring = xccdf_tailoring_get_profiles(tailoring);
 		while (xccdf_profile_iterator_has_more(profit_tailoring)) {
@@ -457,10 +502,11 @@ int xccdf_session_set_profile_id_by_suffix(struct xccdf_session *session, const
 				if (full_profile_id != NULL) {
 					oscap_seterr(OSCAP_EFAMILY_OSCAP, "Multiple matches found:\n%s\n%s\n",
 						full_profile_id, tailoring_profile_id);
-					multiple = true;
+					return_code = OSCAP_PROFILE_MULTIPLE_MATCHES;
 					break;
 				} else {
 					full_profile_id = tailoring_profile_id;
+					return_code = OSCAP_PROFILE_MATCH_OK;
 				}
 			}
 		}
@@ -468,35 +514,16 @@ int xccdf_session_set_profile_id_by_suffix(struct xccdf_session *session, const
 	}
 
 	// Benchmark Profiles
-	if (full_profile_id == NULL) {
-		struct xccdf_profile_iterator *profit_bench = xccdf_benchmark_get_profiles(bench);
-		while (xccdf_profile_iterator_has_more(profit_bench)) {
-			struct xccdf_profile *bench_profile = xccdf_profile_iterator_next(profit_bench);
-			const char *bench_profile_id = xccdf_profile_get_id(bench_profile);
+	if (return_code == OSCAP_PROFILE_NO_MATCH) {
+		full_profile_id = xccdf_benchmark_match_profile_id(bench, profile_suffix, &return_code);
+	}
 
-			if(oscap_str_endswith(bench_profile_id, profile_suffix)) {
-				if (full_profile_id != NULL) {
-					oscap_seterr(OSCAP_EFAMILY_OSCAP, "Multiple matches found:\n%s\n%s\n",
-						full_profile_id, bench_profile_id);
-					multiple = true;
-					break;
-				} else {
-					full_profile_id = bench_profile_id;
-				}
-			}
+	if (return_code == OSCAP_PROFILE_MATCH_OK) {
+		if (!xccdf_session_set_profile_id(session, full_profile_id)) {
+			return_code = OSCAP_PROFILE_NO_MATCH;
 		}
-		xccdf_profile_iterator_free(profit_bench);
-	}
-
-	if (full_profile_id == NULL) {
-		return 1;
-	} else if (multiple) {
-		return 2;
-	} else {
-		const bool search_result = xccdf_session_set_profile_id(session, full_profile_id);
-		assert(search_result);
-		return 0;
 	}
+	return return_code;
 }
 
 const char *xccdf_session_get_profile_id(struct xccdf_session *session)
@@ -1247,16 +1274,17 @@ static int _build_xccdf_result_source(struct xccdf_session *session)
 	}
 
 	/* Build oscap_source of XCCDF TestResult only when needed */
-	if (session->export.xccdf_file != NULL || session->export.report_file != NULL || session->export.arf_file != NULL) {
+	if (session->export.xccdf_file != NULL || session->export.report_file != NULL || session->export.arf_file != NULL || session->export.xccdf_stig_viewer_file != NULL) {
+		const struct xccdf_benchmark *benchmark = xccdf_policy_model_get_benchmark(session->xccdf.policy_model);
+
 		if (session->xccdf.result == NULL) {
 			// Attempt to export session before evaluation
 			oscap_seterr(OSCAP_EFAMILY_OSCAP, "No XCCDF results to export.");
 			return 1;
 		}
-		xccdf_benchmark_add_result(xccdf_policy_model_get_benchmark(session->xccdf.policy_model),
-				xccdf_result_clone(session->xccdf.result));
-		session->xccdf.result_source = xccdf_benchmark_export_source(
-				xccdf_policy_model_get_benchmark(session->xccdf.policy_model), session->export.xccdf_file);
+		struct xccdf_result* cloned_result = xccdf_result_clone(session->xccdf.result);
+		xccdf_benchmark_add_result(benchmark, cloned_result);
+		session->xccdf.result_source = xccdf_benchmark_export_source(benchmark, session->export.xccdf_file);
 
 		if (session->export.xccdf_file != NULL) {
 			// Export XCCDF result file only when explicitly requested
@@ -1267,6 +1295,15 @@ static int _build_xccdf_result_source(struct xccdf_session *session)
 			}
 		}
 
+		if (session->export.xccdf_stig_viewer_file != NULL) {
+			struct oscap_source * stig_result = xccdf_result_stig_viewer_export_source(cloned_result, session->export.xccdf_stig_viewer_file);
+			if (oscap_source_save_as(stig_result, NULL) != 0) {
+				oscap_seterr(OSCAP_EFAMILY_OSCAP, "Could not save file: %s",
+						oscap_source_readable_origin(stig_result));
+				return -1;
+			}
+		}
+
 		/* validate XCCDF Results */
 		if (session->validate && session->full_validation) {
 			if (oscap_source_validate(session->xccdf.result_source, _reporter, NULL)) {
