@@ -94,7 +94,7 @@ void *__oscap_reallocf(void *p, size_t s)
 	m = realloc(p, s);
 	__oscap_err_check(m);
 	if (m == NULL && s > 0) {
-		oscap_free(p);
+		free(p);
 #if defined(OSCAP_ALLOC_EXIT)
 		exit(ENOMEM);
 #endif
@@ -112,80 +112,4 @@ void __oscap_free(void *p)
 	return;
 }
 
-#else
-/*
- * Debug
- */
-
-void *__oscap_alloc_dbg(size_t s, const char *func, size_t line)
-{
-	void *m;
-#if defined(OSCAP_ALLOC_STRICT)
-	assume_d (s > 0, NULL);
-#endif
-	m = malloc(s);
-	__oscap_err_check(m);
-#if defined(OSCAP_ALLOC_EXIT)
-	if (m == NULL)
-		exit(ENOMEM);
-#endif
-	return (m);
-}
-
-void *__oscap_calloc_dbg(size_t n, size_t s, const char *f, size_t l)
-{
-	void *m;
-#if defined(OSCAP_ALLOC_STRICT)
-	assume_d (n > 0, NULL);
-	assume_d (s > 0, NULL);
-#endif
-	m = calloc(n, s);
-	__oscap_err_check(m);
-#if defined(OSCAP_ALLOC_EXIT)
-	if (m == NULL)
-		exit(ENOMEM);
-#endif
-	return (m);
-}
-
-void *__oscap_realloc_dbg(void *p, size_t s, const char *f, size_t l)
-{
-	void *m;
-	m = realloc(p, s);
-	__oscap_err_check(m);
-#if defined(OSCAP_ALLOC_EXIT)
-	if (m == NULL && s > 0)
-		exit(ENOMEM);
-#endif
-	return (m);
-}
-
-void *__oscap_reallocf_dbg(void *p, size_t s, const char *f, size_t l)
-{
-	void *m;
-	m = realloc(p, s);
-	__oscap_err_check(m);
-	if (m == NULL && s > 0) {
-		oscap_free(p);
-#if defined(OSCAP_ALLOC_EXIT)
-		exit(ENOMEM);
-#endif
-	}
-	return (m);
-}
-
-void __oscap_free_dbg(void **p, const char *f, size_t l)
-{
-	assume_d (p != NULL, /* void */);
-#if defined(OSCAP_ALLOC_STRICT)
-	assume_d (*p != NULL, /* void */);
-#endif
-	if (*p != NULL) {
-		free(*p);
-#if defined(OSCAP_ALLOC_RESET)
-		*p = NULL;
-#endif
-	}
-	return;
-}
 #endif
