@@ -25,26 +25,24 @@
 #include "config.h"
 #endif
 
-#ifdef HAVE_BZ2
-
-#include <bzlib.h>
 #include <libxml/tree.h>
 #include <stdlib.h>
 #include <string.h>
 #include <unistd.h>
 
-
 #include "bz2_priv.h"
 #include "common/_error.h"
 
+#ifdef HAVE_BZ2
+
+#include <bzlib.h>
+
 struct bz2_file {
 	FILE *f;
 	BZFILE *file;
 	bool eof;
 };
 
-static const char magic_number[] = {'B','Z'};
-
 static struct bz2_file *bz2_fd_open(int fd)
 {
 	struct bz2_file *b = NULL;
@@ -95,7 +93,7 @@ static int bz2_file_close(void *bzfile)
 	int bzerror;
 	BZ2_bzReadClose(&bzerror, ((struct bz2_file *)bzfile)->file);
 	fclose(((struct bz2_file *)bzfile)->f);
-	oscap_free(bzfile);
+	free(bzfile);
 	return bzerror == BZ_OK ? 0 : -1;
 }
 
@@ -115,14 +113,14 @@ struct bz2_mem {
 
 static void bz2_mem_free(struct bz2_mem *bzmem)
 {
-	oscap_free(bzmem->stream);
-	oscap_free(bzmem);
+	free(bzmem->stream);
+	free(bzmem);
 }
 
 static struct bz2_mem *bz2_mem_open(const char *buffer, size_t size)
 {
-	struct bz2_mem *b = oscap_calloc(sizeof(struct bz2_mem), 1);
-	b->stream = oscap_calloc(sizeof(bz_stream), 1);
+	struct bz2_mem *b = calloc(sizeof(struct bz2_mem), 1);
+	b->stream = calloc(sizeof(bz_stream), 1);
 	// next_in should point at the compressed data
 	b->stream->next_in = (char *) buffer;
 	// and avail_in should indicate how many bytes the library may read
@@ -182,6 +180,10 @@ xmlDoc *bz2_mem_read_doc(const char *buffer, size_t size)
 	return xmlReadIO((xmlInputReadCallback) bz2_mem_read, bz2_mem_close, bzmem, "url", NULL, XML_PARSE_PEDANTIC);
 }
 
+#endif
+
+static const char magic_number[] = {'B','Z'};
+
 bool bz2_memory_is_bzip(const char* memory, const size_t size){
 	if (size < 2){
 		return false; // Cannot read magic number
@@ -211,4 +213,3 @@ bool bz2_fd_is_bzip(int fd)
 	return is_bzip;
 
 }
-#endif
