@@ -19,10 +19,7 @@
 
 set -e -o pipefail
 
-. $srcdir/../../../test_common.sh
-
-assert_exists() { [ $($XPATH $result 'count('"$2"')') == "$1" ]; }
-export -f assert_exists
+. ../../../test_common.sh
 
 #
 # Export two values from XCCDF to a single OVAL variable as a part
