@@ -19,6 +19,8 @@ function test_perl_import {
 # Testing.
 test_init "test_perl.log"
 
-test_run "perl_import" test_perl_import
+if [ -z ${CUSTOM_OSCAP+x} ] ; then
+    test_run "perl_import" test_perl_import
+fi
 
 test_exit
