@@ -3,7 +3,7 @@
 # Author:
 #   Martin Preisler <mpreisle@redhat.com>
 
-. ${srcdir}/../test_common.sh
+. ../test_common.sh
 
 # Test Cases.
 
@@ -14,6 +14,8 @@ function test_python_import {
 # Testing.
 test_init "test_python.log"
 
-test_run "python_import" test_python_import
+if [ -z ${CUSTOM_OSCAP+x} ] ; then
+    test_run "python_import" test_python_import
+fi
 
 test_exit
