@@ -384,11 +384,6 @@ bool check_verbose_options(struct oscap_action *action)
 			"Verbosity level is not specified! Please provide --verbose VERBOSITY_LEVEL option together with --verbose-log-file.");
 		return false;
 	}
-	if (action->verbosity_level != NULL && action->f_verbose_log == NULL) {
-		oscap_module_usage(action->module, stderr,
-			"Log file is not specified! Please provide --verbose-log-file FILE option together with --verbose.");
-		return false;
-	}
 	if (action->verbosity_level != NULL && oscap_verbosity_level_from_cstr(action->verbosity_level) == -1) {
 		oscap_module_usage(action->module, stderr,
 			"Invalid verbosity level! Verbosity level must be one of: DEVEL, INFO, WARNING, ERROR.");
@@ -396,3 +391,13 @@ bool check_verbose_options(struct oscap_action *action)
 	}
 	return true;
 }
+
+void download_reporting_callback(bool warning, const char *format, ...)
+{
+	FILE *dest = stderr;
+	va_list argptr;
+	va_start(argptr, format);
+	vfprintf(dest, format, argptr);
+	va_end(argptr);
+	fflush(dest);
+}
