@@ -50,6 +50,10 @@
 #include "oscap_source.h"
 #include <oscap_debug.h>
 
+#ifndef O_NOFOLLOW
+#define O_NOFOLLOW 0
+#endif
+
 static int app_evaluate_xccdf(const struct oscap_action *action);
 static int app_xccdf_validate(const struct oscap_action *action);
 static int app_xccdf_resolve(const struct oscap_action *action);
@@ -60,8 +64,11 @@ static bool getopt_generate(int argc, char **argv, struct oscap_action *action);
 static int app_xccdf_xslt(const struct oscap_action *action);
 static int app_generate_fix(const struct oscap_action *action);
 
-static struct oscap_module* XCCDF_SUBMODULES[];
-static struct oscap_module* XCCDF_GEN_SUBMODULES[];
+#define XCCDF_SUBMODULES_NUM		8
+#define XCCDF_GEN_SUBMODULES_NUM	5 /* See actual arrays
+						initialization below. */
+static struct oscap_module* XCCDF_SUBMODULES[XCCDF_SUBMODULES_NUM];
+static struct oscap_module* XCCDF_GEN_SUBMODULES[XCCDF_GEN_SUBMODULES_NUM];
 
 struct oscap_module OSCAP_XCCDF_MODULE = {
     .name = "xccdf",
@@ -150,6 +157,7 @@ static struct oscap_module XCCDF_EVAL = {
         "   --export-variables\r\t\t\t\t - Export OVAL external variables provided by XCCDF.\n"
         "   --results <file>\r\t\t\t\t - Write XCCDF Results into file.\n"
         "   --results-arf <file>\r\t\t\t\t - Write ARF (result data stream) into file.\n"
+        "   --stig-viewer <file>\r\t\t\t\t - Writes XCCDF results into FILE in a format readable by DISA STIG Viewer\n"
         "   --thin-results\r\t\t\t\t - Thin Results provides only minimal amount of information in OVAL/ARF results.\n"
         "                 \r\t\t\t\t   The option --without-syschar is automatically enabled when you use Thin Results.\n"
         "   --without-syschar \r\t\t\t\t - Don't provide system characteristic in OVAL/ARF result files.\n"
@@ -187,6 +195,7 @@ static struct oscap_module XCCDF_REMEDIATE = {
 			"  --fetch-remote-resources\r\t\t\t\t - Download remote content referenced by XCCDF.\n"
 			"  --results <file>\r\t\t\t\t - Write XCCDF Results into file.\n"
 			"  --results-arf <file>\r\t\t\t\t - Write ARF (result data stream) into file.\n"
+			"  --stig-viewer <file>\r\t\t\t\t - Writes XCCDF results into FILE in a format readable by DISA STIG Viewer\n"
 			"  --report <file>\r\t\t\t\t - Write HTML report into file.\n"
 			"  --oval-results\r\t\t\t\t - Save OVAL results.\n"
 			"  --export-variables\r\t\t\t\t - Export OVAL external variables provided by XCCDF.\n"
@@ -203,7 +212,7 @@ static struct oscap_module XCCDF_REMEDIATE = {
 
 #define GEN_OPTS \
         "Generate options:\n" \
-        "   --profile <profile-id>\r\t\t\t\t - Tailor XCCDF file with respect to a profile.\n"
+        "   --profile <profile-id>\r\t\t\t\t - Apply profile with given ID to the Benchmark before further processing takes place.\n"
 
 static struct oscap_module XCCDF_GENERATE = {
     .name = "generate",
@@ -262,6 +271,10 @@ static struct oscap_module XCCDF_GEN_FIX = {
 		"   --benchmark-id <id> \r\t\t\t\t - ID of XCCDF Benchmark in some component in the datastream that should be used.\n"
 		"                   \r\t\t\t\t   (only applicable for source datastreams)\n"
 		"   --xccdf-id <id> \r\t\t\t\t - ID of component-ref with XCCDF in the datastream that should be evaluated.\n"
+		"                   \r\t\t\t\t   (only applicable for source datastreams)\n"
+		"   --tailoring-file <file>\r\t\t\t\t - Use given XCCDF Tailoring file.\n"
+		"                   \r\t\t\t\t   (only applicable for source datastreams)\n"
+		"   --tailoring-id <component-id>\r\t\t\t\t - Use given DS component as XCCDF Tailoring file.\n"
 		"                   \r\t\t\t\t   (only applicable for source datastreams)\n",
     .opt_parser = getopt_xccdf,
     .user = "legacy-fix.xsl",
@@ -282,7 +295,7 @@ static struct oscap_module XCCDF_GEN_CUSTOM = {
     .func = app_xccdf_xslt
 };
 
-static struct oscap_module* XCCDF_GEN_SUBMODULES[] = {
+static struct oscap_module* XCCDF_GEN_SUBMODULES[XCCDF_GEN_SUBMODULES_NUM] = {
     &XCCDF_GEN_REPORT,
     &XCCDF_GEN_GUIDE,
     &XCCDF_GEN_FIX,
@@ -290,7 +303,7 @@ static struct oscap_module* XCCDF_GEN_SUBMODULES[] = {
     NULL
 };
 
-static struct oscap_module* XCCDF_SUBMODULES[] = {
+static struct oscap_module* XCCDF_SUBMODULES[XCCDF_SUBMODULES_NUM] = {
     &XCCDF_EVAL,
     &XCCDF_RESOLVE,
     &XCCDF_VALIDATE,
@@ -441,19 +454,46 @@ static void _register_progress_callback(struct xccdf_session *session, bool prog
 	/* xccdf_policy_model_register_output_callback(policy_model, callback_syslog_result, NULL); */
 }
 
-static void report_missing_profile(const struct oscap_action *action)
+void report_missing_profile(const char *profile_suffix, const char *source_file)
 {
 	fprintf(stderr,
 		"No profile matching suffix \"%s\" was found. Get available profiles using:\n"
-		"$ oscap info \"%s\"\n", action->profile, action->f_xccdf);
+		"$ oscap info \"%s\"\n", profile_suffix, source_file);
 }
 
-static void report_multiple_profile_matches(const struct oscap_action *action)
+void report_multiple_profile_matches(const char *profile_suffix, const char *source_file)
 {
 	fprintf(stderr,
-		"At least two profiles matched the given suffix. Use a more specific suffix "
+		"At least two profiles matched suffix \"%s\". Use a more specific suffix "
 		"to get an exact match. Get list of profiles using:\n"
-		"$ oscap info \"%s\"\n", action->f_xccdf);
+		"$ oscap info \"%s\"\n", profile_suffix, source_file);
+}
+
+int evaluate_suffix_match_result_with_custom_reports(int suffix_match_result, const char *profile_suffix, const char *source_file,
+		void (* report_missing)(const char *, const char *), void (* report_multiple)(const char *, const char *))
+{
+	if (suffix_match_result == OSCAP_PROFILE_NO_MATCH) {
+		if (report_missing)
+			report_missing(profile_suffix, source_file);
+		return OSCAP_ERROR;
+	} else if (suffix_match_result == OSCAP_PROFILE_MULTIPLE_MATCHES) {
+		if (report_multiple)
+			report_multiple(profile_suffix, source_file);
+		return OSCAP_ERROR;
+	}
+	return OSCAP_OK;
+}
+
+int evaluate_suffix_match_result(int suffix_match_result, const char *profile_suffix, const char *source_file)
+{
+	return evaluate_suffix_match_result_with_custom_reports(suffix_match_result, profile_suffix, source_file, &report_missing_profile, &report_multiple_profile_matches);
+}
+
+int xccdf_set_profile_or_report_bad_id(struct xccdf_session *session, const char *profile_id, const char *source_file)
+{
+	const int suffix_match_result = xccdf_session_set_profile_id_by_suffix(session, profile_id);
+	int return_code = evaluate_suffix_match_result(suffix_match_result, profile_id, source_file);
+	return return_code;
 }
 
 /**
@@ -501,17 +541,12 @@ int app_evaluate_xccdf(const struct oscap_action *action)
 	if (xccdf_session_load(session) != 0)
 		goto cleanup;
 
+
 	/* Select profile */
 	if (!xccdf_session_set_profile_id(session, action->profile)) {
 		if (action->profile != NULL) {
-			const int suffix_match_result = xccdf_session_set_profile_id_by_suffix(session, action->profile);
-			if (suffix_match_result == 1) {
-				report_missing_profile(action);
+			if (xccdf_set_profile_or_report_bad_id(session, action->profile, action->f_xccdf) == OSCAP_ERROR)
 				goto cleanup;
-			} else if (suffix_match_result == 2) {
-				report_multiple_profile_matches(action);
-				goto cleanup;
-			}
 		} else {
 			fprintf(stderr, "No Policy was found for default profile.\n");
 			goto cleanup;
@@ -546,11 +581,12 @@ int app_evaluate_xccdf(const struct oscap_action *action)
 	}
 
 	xccdf_session_set_xccdf_export(session, action->f_results);
+	xccdf_session_set_xccdf_stig_viewer_export(session, action->f_results_stig);
 	xccdf_session_set_report_export(session, action->f_report);
 	if (xccdf_session_export_xccdf(session) != 0)
 		goto cleanup;
 	else if (action->validate && getenv("OSCAP_FULL_VALIDATION") != NULL &&
-		(action->f_results || action->f_report || action->f_results_arf))
+		(action->f_results || action->f_report || action->f_results_arf || action->f_results_stig))
 		fprintf(stdout, "XCCDF Results are exported correctly.\n");
 
 	if (xccdf_session_export_arf(session) != 0)
@@ -614,7 +650,7 @@ static int app_xccdf_export_oval_variables(const struct oscap_action *action)
 	policy = xccdf_policy_model_get_policy_by_id(xccdf_session_get_policy_model(session), action->profile);
 	if (policy == NULL) {
 		if (action->profile != NULL)
-			report_missing_profile(action);
+			report_missing_profile(action->profile, action->f_xccdf);
 		else
 			fprintf(stderr, "No Policy was found for default profile.\n");
 		goto cleanup;
@@ -667,6 +703,7 @@ int app_xccdf_remediate(const struct oscap_action *action)
 	xccdf_session_set_oval_variables_export(session, action->export_variables);
 	xccdf_session_set_arf_export(session, action->f_results_arf);
 	xccdf_session_set_xccdf_export(session, action->f_results);
+	xccdf_session_set_xccdf_stig_viewer_export(session, action->f_results_stig);
 	xccdf_session_set_report_export(session, action->f_report);
 
 	if (xccdf_session_export_oval(session) != 0)
@@ -893,14 +930,8 @@ int app_generate_fix(const struct oscap_action *action)
 		/* Profile-oriented fixes */
 		if (!xccdf_session_set_profile_id(session, action->profile)) {
 			if (action->profile != NULL) {
-				const int suffix_match_result = xccdf_session_set_profile_id_by_suffix(session, action->profile);
-				if (suffix_match_result == 1) {
-					report_missing_profile(action);
+				if (xccdf_set_profile_or_report_bad_id(session, action->profile, action->f_xccdf) == OSCAP_ERROR)
 					goto cleanup2;
-				} else if (suffix_match_result == 2) {
-					report_multiple_profile_matches(action);
-					goto cleanup2;
-				}
 			} else {
 				fprintf(stderr, "No Policy was found for default profile.\n");
 				goto cleanup2;
@@ -981,6 +1012,7 @@ bool getopt_generate(int argc, char **argv, struct oscap_action *action)
 
 enum oval_opt {
     XCCDF_OPT_RESULT_FILE = 1,
+    XCCDF_OPT_RESULT_FILE_STIG,
     XCCDF_OPT_RESULT_FILE_ARF,
     XCCDF_OPT_DATASTREAM_ID,
     XCCDF_OPT_XCCDF_ID,
@@ -1018,6 +1050,7 @@ bool getopt_xccdf(int argc, char **argv, struct oscap_action *action)
 		{"output",		required_argument, NULL, XCCDF_OPT_OUTPUT},
 		{"results", 		required_argument, NULL, XCCDF_OPT_RESULT_FILE},
 		{"results-arf",		required_argument, NULL, XCCDF_OPT_RESULT_FILE_ARF},
+		{"stig-viewer", 	required_argument, NULL, XCCDF_OPT_RESULT_FILE_STIG},
 		{"datastream-id",		required_argument, NULL, XCCDF_OPT_DATASTREAM_ID},
 		{"xccdf-id",		required_argument, NULL, XCCDF_OPT_XCCDF_ID},
 		{"benchmark-id",		required_argument, NULL, XCCDF_OPT_BENCHMARK_ID},
@@ -1061,6 +1094,7 @@ bool getopt_xccdf(int argc, char **argv, struct oscap_action *action)
 		switch (c) {
 		case XCCDF_OPT_OUTPUT:
 		case XCCDF_OPT_RESULT_FILE:	action->f_results = optarg;	break;
+		case XCCDF_OPT_RESULT_FILE_STIG: action->f_results_stig = optarg;	break;
 		case XCCDF_OPT_RESULT_FILE_ARF:	action->f_results_arf = optarg;	break;
 		case XCCDF_OPT_DATASTREAM_ID:	action->f_datastream_id = optarg;	break;
 		case XCCDF_OPT_XCCDF_ID:	action->f_xccdf_id = optarg; break;
